@@ -1,5 +1,5 @@
-import sys
 import inspect
+import sys
 
 from django.conf import settings
 
@@ -9,7 +9,7 @@ def add_entities(request):
     for name, obj in inspect.getmembers(
         sys.modules['apis_core.apis_entities.models'], inspect.isclass
     ):
-        if obj.__module__ == 'apis_core.apis_entities.models':
+        if obj.__module__ == 'apis_core.apis_entities.models' and name != "AbstractEntity" and name != "ent_class":
             ent_list.append(str(name).lower())
     res = {
         'entities_list': ent_list,
@@ -23,7 +23,7 @@ def add_relations(request):
     for name, obj in inspect.getmembers(
         sys.modules['apis_core.apis_relations.models'], inspect.isclass
     ):
-        if obj.__module__ == 'apis_core.apis_relations.models':
+        if obj.__module__ == 'apis_core.apis_relations.models' and name not in ["AbstractRelation", "AnnotationRelationLinkManager", "ent_class"]:
             relations_list.append(str(name).lower())
     res = {
         'relations_list': relations_list,
@@ -42,4 +42,8 @@ def add_apis_settings(request):
         res['highlighter_active'] = True
     else:
         res['highlighter_active'] = False
+    if 'apis_bibsonomy' in settings.INSTALLED_APPS:
+        res['bibsonomy_active'] = True
+    else:
+        res['bibsonomy_active'] = False
     return res
